===================
Developer's Guide
===================
The developer guide is directed to fellow coders. You should read this if you want to contribute to the development or gain a greater understanding of the code that powers Chanjo.

Currently the best resource on this topic is available at GitHub, in the `CONTRIBUTING.md`_ file.

License
--------
.. include:: ../LICENSE

.. Design concepts / Conventions
    - Generators
    - Pipelines
    - Point to SQL structure
    - Coordinate system (1:1)
      - vs. BED
      - Copy previous + update
    - Why it doesn't do more than this? Why not generate a report
  - Motivation
    - vs. BEDTools and PicardTools
    - Clinical sequencing vs. research
  - Dictionary
    - Completeness
  - Development
    - Git branch structure
      - GitHub flow
    - Testing Chanjo
      - py.test
      - travis
    - Building docs


.. _CONTRIBUTING.md: https://github.com/robinandeer/chanjo/blob/master/CONTRIBUTING.md
